# Solaris makefile for VisualAge executable module
#  w/VM in shared object

PLATFORM   = solaris

BUILDDIR   = /u1/cblythe/test
BASEDIR    = /opt/IBMvast
CALLINDIR  = $(BASEDIR)/callin

DLLVXT     = $(BASEDIR)/bin/abtvxt40.so
SRCSAMP    = $(CALLINDIR)/csamp.c
OBJSAMP    = $(BUILDDIR)/csamp.o
EXESAMP    = $(BUILDDIR)/csamp

CC         = /usr/ucb/cc
LINK       = /usr/ucb/cc
RM         = rm      

# CPPFLAGS:             C preprocessor flags
#
#       -DSOLARIS       Setup ES .h files for Solaris
#       -I$(COMMONDIR)  Common files
#
CPPFLAGS = -DSOLARIS -I$(CALLINDIR)

# CFLAGS:               C compiler flags
#
#       -c              Compile only
#       -mt             Compile multi-threaded
#       -o $@           Use target as output filename
#       -O              Level 2 optimization
#       -KPIC           Generate position independent code
#       -Xa             Compile assuming ANSI C conformance, allow K & R extensions
#       -xCC            Allow C++ stype comments
#       -misalign       Allow proper loads and stores of misaligned data
#
CFLAGS = -misalign -c -mt -o $@ -g -KPIC -Xa -xCC 

# LFLAGS:               Linker flags
#
#       -B static       Link libs statically
#       -G              Link as shared object
#       -o $@           Use target as output filename
#       -R ...          Record the LD_RUN_PATH
#
LFLAGS = -o $@ -R /usr/openwin/lib:/usr/ucblib:/usr/dt/lib:/opt/IBMvast/bin:/opt/IBMvast/odbc/bin

# LIBS:                 Order is important!!
#       -lthread        Threads library
#       -lposix4        POSIX library
#       -lm             SVID math library
#       -ldl            Dynamic loader library
#       -lc             C runtime library
#
LIBS   =  -lthread -lposix4 -lm -ldl -lc  


all: $(EXESAMP) 

clean:
	- $(RM) $(EXESAMP) $(OBJSAMP)

$(EXESAMP): $(OBJSAMP) $(DLLVXT)
	$(LINK) $(OBJSAMP) $(DLLVXT) $(LIBS) $(LFLAGS)

$(OBJSAMP): $(SRCSAMP) 
	$(CC) $(CPPFLAGS) $(CFLAGS) $(SRCSAMP) 
