#!/bin/ksh
#
# Post install script for establishing linkage
# between the exploiting product and NetQuestion
#
# $1 represents the locale, i.e., en_US, Ja_JP, etc.

# _vaVersion represents the version of VA we are installing help for
_vaVersion=5.5

# _productDir represents the product installation directory
_productDir=/opt/IBMvast/$_vaVersion

# _index represents the '?' in the install instructions
# n is for SBCS, q is for DBCS
# assume SBCS
_index=n
if [ "$1" = "Ja_JP" ] || [ "$1" = "ko_KR" ]
then
	_index=q
fi

#_tmp=`echo $1 | tr '[A-Z]' '[a-z]'`
#_tmp2=${_tmp#???}
_tmp=${1%???}
typeset -l _tmp2=${1#???}

# _lang represents the locale in lowercase without the '_'
#_lang=${_tmp%???}$_tmp2
_lang=${_tmp}$_tmp2

# cgi step 1
if [ ! -d /usr/docsearch/cgi-bin ]
  then
    mkdir /usr/docsearch/cgi-bin
fi

# Since the -f switch on the ln command on Solaris doesn't force
# the new link, we must manually remove it first
rm /usr/docsearch/cgi-bin/abtwebx.exe

ln -fs ${_productDir}/bin/abtwebx.exe\
      /usr/docsearch/cgi-bin/abtwebx.exe

# here is the logic to determine the name of the 
# search engine .exe
if [ "$1" = "en_US" ]
then
	_eng=abtsrsen.exe
else
	if [ "$_index" = "n" ]
	then _tmp3=s
	else _tmp3=d
	fi
	_eng=abtsr${_tmp3}${_tmp2}.exe
fi

# Since the -f switch on the ln command on Solaris doesn't force
# the new link, we must manually remove it first
rm /usr/docsearch/cgi-bin/${_eng}

ln -fs ${_productDir}/bin/${_eng}\
      /usr/docsearch/cgi-bin/${_eng}


# cgi step 2
if [ ! -d /usr/docsearch/html ]
  then
    mkdir /usr/docsearch/html
fi

ln -fs ${_productDir}/help/${1}/abtfoot.htm\
      /usr/docsearch/html/abtfoot.htm

ln -fs ${_productDir}/help/${1}/abthead*.htm\
      /usr/docsearch/html

if [ "$1" = "en_US" ]
then
	ln -fs ${_productDir}/help/${1}/abtstar*\
      		/usr/docsearch/html
fi

#call to cgi_config.sh
./cgi_config.sh abtwebx.exe $_eng

for _indexDir in ${_productDir}/help/${1}/abtx*
do
	_abtIndex=$(basename $_indexDir)
	
	#
	# create index directories
	#
	mkdir -p /usr/docsearch/indexes/${_abtIndex}/data
	mkdir /usr/docsearch/indexes/${_abtIndex}/admtb

	# step 4
	ln -s ${_indexDir}/im*\
	      /usr/docsearch/indexes/${_abtIndex}/data

	if [ "$_index" = "q" ]
	then
		# create links required for DBCS only
		for _file in ${_indexDir}/abtx*
		do
		typeset -u _ufile=$(basename $_file)
		ln -s $_file /usr/docsearch/indexes/${_abtIndex}/data/$_ufile
		done
	fi

	#
	# Remove links that will be created later on with a different target.
	#
	rm /usr/docsearch/indexes/${_abtIndex}/data/im${_index}admtb.dat
	rm /usr/docsearch/indexes/${_abtIndex}/data/im${_index}iq.dat

	# step 1
	ln -s /var/docsearch/indexes/${_abtIndex}/data/im${_index}admtb.dat\
	      /usr/docsearch/indexes/${_abtIndex}/data/im${_index}admtb.dat 

	# step 2
	ln -s /var/docsearch/indexes/${_abtIndex}/data/im${_index}iq.dat\
	      /usr/docsearch/indexes/${_abtIndex}/data/im${_index}iq.dat 

	# step 3
	ln -s /var/docsearch/indexes/${_abtIndex}/work\
	      /usr/docsearch/indexes/${_abtIndex}/work 

	# step 5
	ln -s ${_indexDir}/im${_index}admtb.dat\
	      /usr/docsearch/indexes/${_abtIndex}/admtb/im${_index}admtb.dat

	# step 6
	ln -s ${_indexDir}/im${_index}iq.dat\
	      /usr/docsearch/indexes/${_abtIndex}/admtb/im${_index}iq.dat

	#call to ix_config.sh
	if [ "$_index" = "n" ]
	then _type=SBCS
	else 
	  _type=DBCS
	fi

	# determine the name of the zip file that corresponds to this index
	_abtZipName=abtz${_abtIndex#abtx}
	
	./ix_config.sh $_type $_abtIndex $1 $_vaVersion $_abtZipName

	#
	# Create imqkeep.it for DBCS only.
	# SBCS imnkeep.it is created by ix_config.sh
	# This code was copied from above to ensure
	# the existence of the /var/docsearch path
	# created by ix_config.sh.
	#
	if [ "$_index" = "q" ]
	then 
	  touch /var/docsearch/indexes/${_abtIndex}/work/imqkeep.it
	fi
done
